pub fn request_stop()Expand description
Requests that the audio system stop.
This is safe to call from a signal handler or an auxiliary thread.
pub fn request_stop()Requests that the audio system stop.
This is safe to call from a signal handler or an auxiliary thread.